<?php
/* ======================================================
 # Limit Active Logins for Joomla! - v1.1.3 (free version)
 # -------------------------------------------------------
 # For Joomla! CMS (v3.x)
 # Author: Web357 (Yiannis Christodoulou)
 # Copyright (©) 2014-2023 Web357. All rights reserved.
 # License: GNU/GPLv3, http://www.gnu.org/licenses/gpl-3.0.html
 # Website: https:/www.web357.com
 # Demo: https://limitactivelogins.web357.com/
 # Support: support@web357.com
 # Last modified: Wednesday 20 March 2024, 12:24:05 PM
 ========================================================= */

defined('_JEXEC') or die;

use \Joomla\CMS\Language\Text;

JLoader::register('LimitactiveloginsHelper', JPATH_ADMINISTRATOR . DIRECTORY_SEPARATOR . 'components' . DIRECTORY_SEPARATOR . 'com_limitactivelogins' . DIRECTORY_SEPARATOR . 'helpers' . DIRECTORY_SEPARATOR . 'limitactivelogins.php');

use \Joomla\CMS\Factory;
use \Joomla\CMS\MVC\Model\BaseDatabaseModel;

/**
 * Class LimitactiveloginsFrontendHelper
 *
 * @since  1.6
 */
class LimitactiveloginsHelpersLimitactivelogins
{
	/**
	 * Get an instance of the named model
	 *
	 * @param   string  $name  Model name
	 *
	 * @return null|object
	 */
	public static function getModel($name)
	{
		$model = null;

		// If the file exists, let's
		if (file_exists(JPATH_SITE . '/components/com_limitactivelogins/models/' . strtolower($name) . '.php'))
		{
			require_once JPATH_SITE . '/components/com_limitactivelogins/models/' . strtolower($name) . '.php';
			$model = BaseDatabaseModel::getInstance($name, 'LimitactiveloginsModel');
		}

		return $model;
	}

	/**
	 * Gets the files attached to an item
	 *
	 * @param   int     $pk     The item's id
	 *
	 * @param   string  $table  The table's name
	 *
	 * @param   string  $field  The field's name
	 *
	 * @return  array  The files
	 */
	public static function getFiles($pk, $table, $field)
	{
		$db = Factory::getDbo();
		$query = $db->getQuery(true);

		$query
			->select($field)
			->from($table)
			->where('id = ' . (int) $pk);

		$db->setQuery($query);

		return explode(',', $db->loadResult());
	}

    /**
     * Gets the edit permission for an user
     *
     * @param   mixed  $item  The item
     *
     * @return  bool
     */
    public static function canUserEdit($item)
    {
        $permission = false;
        $user       = Factory::getUser();

        if ($user->authorise('core.edit', 'com_limitactivelogins'))
        {
            $permission = true;
        }
        else
        {
            if (isset($item->created_by))
            {
                if ($user->authorise('core.edit.own', 'com_limitactivelogins') && $item->created_by == $user->id)
                {
                    $permission = true;
                }
            }
            else
            {
                $permission = true;
            }
        }

        return $permission;
	}
	
	// Time Elapsed from a date (e.g. 14 days ago, just now, 6 minutes ago etc.)
	public static function time_elapsed_string($datetime, $full = false) 
	{
		$offset = JFactory::getConfig()->get('offset');
		$timezone = new DateTimeZone($offset);
		$datetime = JHTML::_('date', $datetime, "Y-m-d H:i:s");
		$datetime_now = new DateTime('now', new DateTimeZone($offset));
		$now = $datetime_now->format('Y-m-d H:i:s');

		$now = new DateTime($now, $timezone);
		$ago = new DateTime($datetime, $timezone);
		$diff = $now->diff($ago);

		$totalDays = $diff->format('%a');  // Get the total number of days

		// Calculate weeks and remaining days
		$weeks = floor($totalDays / 7);
		$remainingDays = $totalDays % 7;

		$string = array(
			'y' => 'year',
			'm' => 'month',
			'd' => 'day',
			'h' => 'hour',
			'i' => 'minute',
			's' => 'second',
		);

		foreach ($string as $key => &$value) {
			if ($diff->$key) {
				$value = $diff->$key . ' ' . Text::_('COM_LIMITACTIVELOGINS_TIME_ELAPSED_STRING_' . strtoupper($value . ($diff->$key > 1 ? 's' : '')));
			} else {
				unset($string[$key]);
			}
		}

		if ($weeks > 0) {
			$string['w'] = $weeks . ' ' . Text::_('COM_LIMITACTIVELOGINS_TIME_ELAPSED_STRING_WEEKS');
		}

		if (!$full) {
			$string = array_slice($string, 0, 1);
		}

		return $string ? implode(', ', $string) . ' ' . Text::_('COM_LIMITACTIVELOGINS_AGO') : Text::_('COM_LIMITACTIVELOGINS_JUST_NOW');
	}
}
